#
# spec file for package conan
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Note: We only want to build for the default python3
Name:           conan
Version:        2.12.2
Release:        1.3
Summary:        A C/C++ package manager
License:        MIT
URL:            https://github.com/conan-io/conan
Source:         https://files.pythonhosted.org/packages/source/c/conan/conan-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
Requires:       python3-Jinja2
Requires:       python3-PyYAML >= 6.0
Requires:       python3-colorama >= 0.4.3
Requires:       python3-distro
Requires:       python3-fasteners >= 0.15
Requires:       python3-patch-ng >= 1.17.4
Requires:       python3-python-dateutil >= 2.8.0
Requires:       python3-requests >= 2.25
Requires:       python3-urllib3 >= 1.26.6
BuildArch:      noarch

%description
Conan is a package manager for C and C++ developers. It is specifically
designed and optimized for accelerating the development and Continuous
Integration of C and C++ projects.

%prep
%autosetup -p1 -n conan-%{version}

%build
%python3_pyproject_wheel

%install
%python3_pyproject_install
%fdupes %{buildroot}%{python3_sitelib}
sed -Ei "1{\@/usr/bin/(env )?python@d}" \
  %{buildroot}%{python3_sitelib}/conan/tools/intel/intel_cc.py \
  %{buildroot}%{python3_sitelib}/conan/test/utils/server_launcher.py

%files
%doc README.md
%license LICENSE.md
%{_bindir}/conan
%{python3_sitelib}/conan/
%{python3_sitelib}/conans/
%{python3_sitelib}/conan-%{version}.dist-info

%changelog
* Sat Feb 15 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.12.2:
  * Fix default name and let cycloneDX define a custom name
    (gh#conan-io/conan#17760).
  * Add cycloneDX add_tests and add_build parameters
    (gh#conan-io/conan#17760).
  * Fix cycloneDX tool parameters (gh#conan-io/conan#17760).
* Sat Feb  8 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 2.12.1:
  * Bugfix: Fix conan config clean not regenerating every necessary file.
  * Bugfix: Avoid compatibility.py migration if any of the files are modified
    by users.
- Update to version 2.12.0:
  * Feature: Make public documented (and experimental) the
  - -build=compatible:[pattern] build mode
  * Feature: Define new tools.cmake.cmaketoolchain:user_presets to customize
    the name of the generated CMakeUserPresets.json
  * Feature: Serialize in --format=json graph output the original requirements
    version range, not only the resolved one.
  * Feature: Add cycloneDX as a Conan tool and implement subgraph for conanfile
  * Feature: Initial conan workspace build command to build the full workspace,
    based on the definition of products.
  * Feature: Allow applying patches on "create" time for conan-center-index
    like layouts from an external centralized folder.
  * Feature: Add report progress while unpacking tarball files.
  * Feature: conan profile show can now select which context's profile to show
  * Feature: Better logging, printing the username for repositories, successful
    auth event and trace-level messages including full URL requests.
  * Feature: Adds conan config clean command that will remove all custom config
    from conan home, excluding the generated packages.
  * Feature: Add reinit method to ConanApi, which reinitializes every subapi.
  * Feature: Allow defining --out-file=file.ext instead of
  - -format=ext > file.ext to write to files directly and avoid issues
    with redirects
  * Feature: Cache HTTP request sessions between API calls.
  * Feature: Implement caching in the Remote objects for RemoteManager calls
  * Fix: Added arch_flag as a public attribute to the MesonToolchain generator.
  * Fix: Increase sqlite timeout from 10 to 20 seconds for very heavily loaded
    CI servers.
  * Fix: Make remotes.json saving transactional to avoid corruption for hard
    killed processes.
  * Fix: Improve error message for conan create when test_package has missing
    binaries.
  * Fix: Fix Git is_dirty detection of excluded files with paths.
  * Fix: Allow latest bottle 0.13 release for conan_server to work with
    Python 3.13.
  * Fix: GnuToolchain's make_args handle empty values correctly.
  * Fix: Fix inconsistency in replace_in_file, that returned False if the
    pattern was not found (with strict off), otherwise None.
  * Fix: conan profile show does not pollute stdout with information titles.
  * Fix: Error out when unknown language is used in languages attribute.
  * Fix: Fix Workspace when using the workspace_api.load() and using self.run()
    inside set_version().
  * Bugfix: conf_build does not exist for cli and conanfile.txt contexts.
  * Bugfix: Make possible to use pattern and strip_root at the same time for
    conan.tools.files.unzip().
  * Bugfix: Solve incubating CMakeDeps issues with transitive
    [replace_requires].
  * Bugfix: Solve PkgConfigDeps issues with transitive [replace_requires].
* Sun Dec 22 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.11.0:
  * Feature: Only warn on frozen conan v1 remote if enabled
    (gh#conan-io/conan#17482).
  * Feature: AutotoolsToolchain uses user's variables when Android
    cross-compilation at first (gh#conan-io/conan#17470).
  * Feature: AutotoolsToolchain checks if Android
    cross-compilation paths exist (gh#conan-io/conan#17470).
  * Feature: Adding the Conan cache "profiles" folder to the
    jinja2 search path, so profiles can be included/imported from
    jinja syntax even for parent and sibling folders
    (gh#conan-io/conan#17432).
  * Feature: Updated tools.env.virtualenv:powershell conf to allow
    specifying the PowerShell executable (e.g., powershell.exe or
    pwsh) and passing additional arguments
    (gh#conan-io/conan#17416).
  * Feature: Deprecate use of
    tools.env.virtualenv:powershell=True/False
    (gh#conan-io/conan#17416).
  * Fix: Do not show powershell deprecation message if value is
    None (gh#conan-io/conan#17500).
  * Fix: Fix LocalAPI definition of editables when calling
    editable_add (gh#conan-io/conan#17498).
  * Fix: Clarify debug message in CMakeDeps
    (gh#conan-io/conan#17453).
  * Fix: Added explicitly allow_empty = True to glob() function in
    BazelDeps (bazel 8.x compatible) (gh#conan-io/conan#17444).
  * Fix: Fix broken cpp_info.location deduction due to unsanitized
    regex (gh#conan-io/conan#17430).
  * Fix: Trusting the real path coming from a symlink is a good
    one (gh#conan-io/conan#17421).
  * Fix: Fix user/channel when searching patterns in a
    local-recipes-index (gh#conan-io/conan#17408).
  * Fix: Add warning for empty version ranges
    (gh#conan-io/conan#17405).
  * Bugfix: Fix bogus duplication of component properties (#17503
  * Bugfix: Fix running commands in powershell with single quotes
    (gh#conan-io/conan#17487).
  * Bugfix: Fix issues with unsetting some types of confs
    (gh#conan-io/conan#17445).
* Wed Oct  9 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.8.0:
  * New features:
  - Add Clang 19 support. (gh#conan-io/conan#17010)
  - conan config list <pattern> to filter available
    configurations. (gh#conan-io/conan#17000)
  - New auth_remote.py plugin for custom user authentication to
    Conan remotes. (gh#conan-io/conan#16942)
  - New auth_source.py plugin for custom user authentication for
    generic downloads of sources. (gh#conan-io/conan#16942)
  - Add --envs-generation={false} to conan install and conan
    build to disable the generation of virtualenvs
    (conanbuildenv.sh|bat and conanrunenv.sh|bat).
    (gh#conan-io/conan#16935)
  - New tools.files.unzip:filter conf that allows to define
    data, tar and fully_trusted extraction policies for tgz
    files. (gh#conan-io/conan#16918)
  - get() and unzip() tools for source() learned a new
    extract_filter argument to define data, tar and
    fully_trusted extraction policies for tgz files.
    (gh#conan-io/conan#16918)
  - Add progress updates for large uploads (>100Mbs) every 10
    seconds. (gh#conan-io/conan#16913)
  - Implement conan config install-pkg --url=<repo-url> for
    initial definition of remote URL when no remotes are defined
    yet. (gh#conan-io/conan#16876)
  - Allow building a compatible package still of the current
    profile one. (gh#conan-io/conan#16871)
  - Allow bootstrapping (depending on another variant of
    yourself), even for the same version.
    (gh#conan-io/conan#16870)
  - Allow [replace_requires] to replace the package name and
    self.dependencies still works with the old name.
    (gh#conan-io/conan#16443)
  * Bugs fixed:
  - Let CMakeToolchain defining CMAKE_SYSTEM_XXX even if
    user_toolchain is defined, but protected in case the
    toolchain really defines them. (gh#conan-io/conan#17036)
  - Replace | character in generated CMake and Environment
    files. (gh#conan-io/conan#17024)
  - Redirect the PkgConfig stderr to the exception raised.
    (gh#conan-io/conan#17020)
  - Use always forward slashes in Windows subsystems bash path.
    (gh#conan-io/conan#16997)
  - Better error messages when conan list
  - -graph=<graph-json-file> file has issues.
    (gh#conan-io/conan#16936)
  - PkgConfigDeps.set_property() was not setting properly all
    the available properties. (gh#conan-io/conan#17051)
  - BazelDeps did not find DLL files as Conan does not model
    them in the Windows platform. (gh#conan-io/conan#17045)
  - Do not skip dependencies of a package if it is not going to
    be skipped due to tools.graph:skip_binaries=False.
    (gh#conan-io/conan#17033)
  - Allow requires(..., package_id_mode) trait in case of
    diamonds to always use the recipe defined one irrespective
    of requires() order. (gh#conan-io/conan#16987)
  - Propagate include_prerelease flag to intersection of
    VersionRange. (gh#conan-io/conan#16986)
  - Raise error if invalid value passed to
    conf.get(check_type=bool). (gh#conan-io/conan#16976)
  - Allow remote_login accept patterns.
    (gh#conan-io/conan#16942)
* Wed Jul 17 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.5.0:
  * Feature: New tools.cmake.cmaketoolchain:enabled_blocks
    configuration to define which blocks of CMakeToolchain should
    be active or not (gh#conan-io/conan#16563).
  * Feature: Allow --filter-options in conan list to use &: scope
    to refer to all packages being listed
    (gh#conan-io/conan#16559).
  * Feature: Highlight missing or invalid requirements while
    computing dependency graph (gh#conan-io/conan#16520).
  * Feature: New conan lock update subcommand to remove + add a
    reference in the same command (gh#conan-io/conan#16511).
  * Feature: Add support for GCC 12.4 (gh#conan-io/conan#16506).
  * Feature: Honoring tools.android:ndk_path conf. Setting the
    needed flags to cross-build for Android
    (gh#conan-io/conan#16502).
  * Feature: Add os.ndk_version for Android
    (gh#conan-io/conan#16494).
  * Feature: Qbs helper now invokes Conan provider automatically
    (gh#conan-io/conan#16486).
  * Feature: Added force option to
    tools.cmake.cmaketoolchain:extra_variables
    (gh#conan-io/conan#16481).
  * Feature: Raising a ConanException if any section is duplicated
    in the same Conan profile file (gh#conan-io/conan#16454).
  * Feature: Added resolve() method to the Qbs toolchain
    (gh#conan-io/conan#16449).
  * Feature: Make MSBuildDeps generation with deployer relocatable
    (gh#conan-io/conan#16441).
  * Feature: Add QbsDeps class to be used with Qbs Conan module
    provider (gh#conan-io/conan#16334).
  * Feature: Add built in runtime_deploy deployer
    (gh#conan-io/conan#15382).
  * Fix: Fix provides conflict error message not showing
    conflicting provides when a named reference matches a provider
    (gh#conan-io/conan#16562).
  * Fix: Set correct testpaths for pytest
    (gh#conan-io/conan#16530).
  * Fix: Allow .conanrc file in the root of a filesystem
    (gh#conan-io/conan#16514).
  * Fix: Add support for non default docker hosts in conan runners
    (#16477)
  * Fix: Don't fail when we can't overwrite the summary file in
    the backup upload (gh#conan-io/conan#16452).
  * Fix: Make source_credentials.json do not apply to Conan server
    repos protocol (gh#conan-io/conan#16425).
  * Fix: Allow packages to have empty folders
    (gh#conan-io/conan#16424).
  * Bugfix: Fix detect_msvc_compiler() from detect_api to properly
    detect VS 17.10 with compiler.version=194
    (gh#conan-io/conan#16581).
  * Bugfix: Fix unexpected error when a recipe performs
    package_id() info erasure and is used as a compatibility
    candidate (gh#conan-io/conan#16575).
  * Bugfix: Ensure msvc cppstd compatibility fallback does not
    ignore 194 binaries (gh#conan-io/conan#16573).
  * Bugfix: XXXDeps generators did not include an absolute path in
    their generated files if --deployer-folder=xxxx param was used
    (gh#conan-io/conan#16552).
  * Bugfix: Fix conan list ... --format=compact for package
    revisions (gh#conan-io/conan#16490).
  * Bugfix: Fix XcodeToolchain when only defines are set
    (gh#conan-io/conan#16429).
* Thu Apr  4 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.2.2:
  * Fix: Avoid issues with recipe `print(..., file=fileobj)`
    (gh#conan-io/conan#15934).
  * Fix: Fix broken calls to `print(x, file=y)` with duplicate
    keyword arguments (gh#conan-io/conan#15912).
  * Bugfix: Fix handling of `tools.build:defines` for multiconfig
    CMake (gh#conan-io/conan#15924).
* Sun Mar 24 2024 Dirk Müller <dmueller@suse.com>
- update to 2.2.1:
  * Fix: Add `copytree_compat` method for compatibility with
    Python>=3.12 after distutils removal.
- update to 2.2.0:
  * Feature: Raise for toolchains different than CMakeToolchain
    if using universal binary syntax.
  * Feature: Warn on misplaced requirement function calls
  * Feature: Print options conflicts in the graph caused by
    different branches recipes defining options values.
  * Feature: Add `--backup-sources` flag to `conan cache clean`.
  * Feature: Add `conan graph outdated` command that lists the
    dependencies that have newer versions in remotes
  * Feature: Add a parameter to `trim_conandata` to avoid raising
    an exception when conandata.yml file doesn't exist.
  * Feature: Added `build_context_folder ` to PkgConfigDeps.
  * Feature: Included `build.pkg_config_path ` in the built-in
    options section in the MesonToolchain template.
  * Feature: Update `_meson_cpu_family_map` to support `arm64ec`.
  * Feature: Added support for Clang 18.
  * Feature: Add basic support in CMakeToolchain for universal
    binaries.
  * Feature: New ``tools.cmake.cmake_layout:build_folder`` config
    that allows re-defining ``cmake_layout`` local build-folder.
  * Feature: New ``tools.cmake.cmake_layout:test_folder`` config
    that allows re-defining ``cmake_layout`` output build folder
    for ``test_package``, including a ``$TMP`` placeholder to
    create a temporary folder in system ``tmp``.
  * Feature: (Experimental) Add ``conan config install-pkg
    myconf/[*]`` new configuration inside Conan packages with new
    ``package_type = "configuration"``.
  * Feature: (Experimental) New ``core.package_id:config_mode``
    that allows configuration package reference to affect the
    ``package_id`` of all packages built with that configuration.
  * Feature: Make `cppstd_flag` public to return the
    corresponding C++ standard flag based on the settings.
  * Feature: Allow ``self.name`` and ``self.version`` in
    ``build_folder_vars`` attribute and conf.
  * Feature: Add ``conan list --filter-xxx`` arguments to list
    package binaries that match settings+options.
  * Feature: Add `detect_libc` to the `detect_api` to get the
    name and version of the C library.
  * Feature: New ``CommandAPI`` subapi in the ``ConanAPI`` that
    allows calling other commands.
  * Fix: Avoid unnecessary build of ``tool_requires`` when
    ``--build=missing`` and repeated ``tool_requires``.
  * Fix: Fix ``CMakeDeps`` ``set_property(... APPEND`` argument
    order.
  * Fix: Raising an error when an infinite loop is found in the
    install graph (ill-formed dependency graph with loops).
  * Fix: Make sure `detect_default_compiler()` always returns a
    3-tuple.
  * Fix: Print a clear message for ``conan graph explain`` when
    no binaries exist for one revision.
  * Fix: Add ``package_type="static-library"`` to the ``conan new
    msbuild_lib`` template.
  * Fix: Avoid ``platform_requires`` to fail when explicit
    options are being passed via ``requires(.., options={})``.
  * Fix: Make ``CMakeToolchain`` end with newline.
  * Fix: Do not allow ``conan list`` binary filters or package
    query if a binary pattern is not provided.
  * Fix: Avoid ``CMakeToolchain.preprocessor_definition``
    definitions to ``"None"`` literal string when it  has no
    value (Python ``None``).
  * Fix: Improved ``conan install  --deployer-package=*`` case
    that was crashing when using ``self.package_folder``.
  * Fix: Fix `conan graph info --format=html` for large
    dependency graphs.
  * Fix: Make all recipe and plugins python file ``print()`` to
    ``stderr``, so json outputs to ``stdout`` are not broken.
  * Fix: Fix getting the gnu triplet for Linux x86.
* Mon Feb 19 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.1.0:
  * Long list of changes, see
    https://github.com/conan-io/conan/releases/tag/2.1.0
* Thu Jan 11 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.17:
  * Fix: Automatically create folder if conan cache save
  - -file=subfolder/file.tgz subfolder doesn't exist
    (gh#conan-io/conan#15409).
  * Bugfix: Fix libcxx detection when using CC/CXX env vars
    (gh#conan-io/conan#15418).
  * Bugfix: Solve winsdk_version bug in CMakeToolchain generator
    for cmake_minimum_required(3.27) (gh#conan-io/conan#15373).
  * Bugfix: Fix visible trait propagation with build=True trait
    (gh#conan-io/conan#15357).
  * Bugfix: Fix package_id calculation when including conf values
    thru tools.info.package_id:confs (gh#conan-io/conan#15356).
  * Bugfix: Order conf items when dumping them to allow
    reproducible package_id independent of the order the confs
    were declared (gh#conan-io/conan#15356).
* Thu Dec 28 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.16:
  * Bugfix: Revert the default of source_buildenv, make it False
    by default [gh#conan-io/conan#15319].
- Changes from version 2.0.15:
  * Feature: New conan lock remove command to remove requires from
    lockfiles [gh#conan-io/conan#15284].
  * Feature: New CMake.ctest() helper method to launch directly
    ctest instead of via cmake --target=RUN_TEST
    [gh#conan-io/conan#15282].
  * Feature: Add tracking syntax in <host_version> for different
    references [gh#conan-io/conan#15274].
  * Feature: Add pkglist formatter for conan export command
    [gh#conan-io/conan#15266].
  * Feature: Define CONAN_LOG_LEVEL env-var to be able to change
    verbosity at a global level [gh#conan-io/conan#15263].
  * Feature: conan cache path xxx --folder xxxx raises an error if
    the folder requested does not exist [gh#conan-io/conan#15257].
  * Feature: Add in operator support for ConanFile's
    self.dependencies [gh#conan-io/conan#15221].
  * Feature: Make CMakeDeps generator create a conandeps.cmake
    that aggregates all direct dependencies in a cmake-like
    generator style [gh#conan-io/conan#15207].
  * Feature: Add build environment information to CMake configure
    preset and run environment information to CMake test presets
    [gh#conan-io/conan#15192].
  * Feature: Removed a warning about a potential issue with conan
    migration that would print every time a build failed
    [gh#conan-io/conan#15174].
  * Feature: New deploy() method in recipes for explicit
    per-recipe deployment [gh#conan-io/conan#15172].
  * Feature: Allow tool-requires to be used in source() method
    injecting environment [gh#conan-io/conan#15153].
  * Feature: Allow accessing the contents of settings.yml (and
    settings_user!) from ConfigAPI [gh#conan-io/conan#15151].
  * Feature: Add builtin conf access from ConfigAPI
    [gh#conan-io/conan#15151].
  * Feature: Add redirect_stdout to CMake integration methods
    [gh#conan-io/conan#15150].
  * Feature: Add core:warnings_as_errors configuration option to
    make Conan raise on warnings and errors
    [gh#conan-io/conan#15149].
  * Feature: Added FTP_TLS option using secure argument in
    ftp_download for secure communication
    [gh#conan-io/conan#15137].
  * Feature: New [replace_requires] and [replace_tool_requires] in
    profile for redefining requires, useful for package
    replacements like zlibng/zlib, to solve conflicts, and to
    replace some dependencies by system alternatives wrapped in
    another Conan package recipe [gh#conan-io/conan#15136].
  * Feature: Add stderr capture argument to conanfile's run()
    method [gh#conan-io/conan#15121].
  * Feature: New [platform_requires] profile definition to be able
    to replace Conan dependencies by platform-provided
    dependencies [gh#conan-io/conan#14871].
  * Feature: New conan graph explain command to search, compare
    and explain missing binaries [gh#conan-io/conan#14694].
  * Feature: Global cpp_info can be used to initialize components
    values [gh#conan-io/conan#13994].
  * Fix: Make core:warnings_as_errors accept a list
    [gh#conan-io/conan#15297].
  * Fix: Fix user confs package scoping when no separator was
    given [gh#conan-io/conan#15296].
  * Fix: Fix range escaping in conflict reports involving ranges
    [gh#conan-io/conan#15222].
  * Fix: Allow hard set_name() and set_version() to mutate name
    and version provided in command line
    [gh#conan-io/conan#15211].
  * Fix: Make conan graph info --format=text print to stdout
    [gh#conan-io/conan#15170].
  * Fix: Avoid warning in CMake output due to
    CMAKE_POLICY_DEFAULT_CMP0091 unused variable
    [gh#conan-io/conan#15127].
  * Fix: Deprecate [system_tools] in favor of
    [platform_tool_requires] to align with [platform_requires] for
    regular dependencies. Changed output from "System tool" to
    "Platform" [gh#conan-io/conan#14871].
  * Bugfix: Ensure user confs have at least 1 : separator
    [gh#conan-io/conan#15296].
  * Bugfix: Git.is_dirty() will use git status . -s to make sure
    it only process the current path, not the whole repo,
    similarly to other Git methods [gh#conan-io/conan#15289].
  * Bugfix: Make self.info.clear() and header-only packages to
    remove python_requires and tool_requires
    [gh#conan-io/conan#15285].
  * Bugfix: Make conan cache save/restore portable across Windows
    and other OSs [gh#conan-io/conan#15253].
  * Bugfix: Do not relativize absolute paths in deployers
    [gh#conan-io/conan#15244].
  * Bugfix: Add architecture to CMakePresets to avoid cmake
    ignoring toolchain definitions when using presets
    [gh#conan-io/conan#15215].
  * Bugfix: Fix conan graph info --format=html reporting
    misleading conflicting nodes [gh#conan-io/conan#15196].
  * Bugfix: Fix serialization of tool_requires in conan profile
    show --format=json [gh#conan-io/conan#15185].
  * Bugfix: Fix NMakeDeps quoting issues
    [gh#conan-io/conan#15140].
  * Bugfix: Fix the 2.0.14 migration to add LRU data to the cache
    when storage_path conf is defined [gh#conan-io/conan#15135].
  * Bugfix: Fix definition of package_metadata_folder for conan
    export-pkg command [gh#conan-io/conan#15126].
  * Bugfix: pyinstaller.py was broken for Python 3.12 due to a
    useless distutils import [gh#conan-io/conan#15116].
  * Bugfix: Fix backup sources error when no
    core.sources:download_cache is set [gh#conan-io/conan#15109].
* Sat Dec 16 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.14:
  * Feature: Added riscv64, riscv32 architectures to default
    settings.yml and management of them in Meson and Autotools
    [gh#conan-io/conan#15053].
  * Feature: Allow only one simultaneous database connection
    [gh#conan-io/conan#15029].
  * Feature: Add conan cache backup-upload to upload all the
    backup sources in the cache, regardless of which references
    they are from [gh#conan-io/conan#15013].
  * Feature: New conan list --format=compact for better UX
    [gh#conan-io/conan#15011].
  * Feature: Ignore metadata upload by passing --metadata=""
    [gh#conan-io/conan#15007].
  * Feature: Better output messages in conan upload
    [gh#conan-io/conan#14984].
  * Feature: Add extra flags to CMakeToolchain
    [gh#conan-io/conan#14966].
  * Feature: Implement package load/restore from the cache, for CI
    workflows and moving packages over air-gaps
    [gh#conan-io/conan#14923].
  * Feature: Compute version-ranges intersection to avoid graph
    version conflicts for compatible ranges
    [gh#conan-io/conan#14912].
  * Feature: CMake helper can use multiple targets in target
    argument [gh#conan-io/conan#14883].
  * Feature: Add CMakeDeps and PkgConfigDeps generators listening
    to system_package_version property [gh#conan-io/conan#14808].
  * Feature: Add shorthand syntax in cli to specify host and build
    in 1 argument [gh#conan-io/conan#14727].
  * Feature: Implement cache LRU control for cleaning of unused
    artifacts [gh#conan-io/conan#14054].
  * Fix: Avoid CMakeToolchain overwriting user CMakePresets.json
    when no layout nor output-folder is defined
    [gh#conan-io/conan#15058].
  * Fix: Add astra, elbrus and altlinux as distribution using apt
    in SystemPackageManager [gh#conan-io/conan#15051].
  * Fix: Default to apt-get package manager in Linux Mint
    [gh#conan-io/conan#15026].
  * Fix: Make Git() check commits in remote server even for
    shallow clones [gh#conan-io/conan#15023].
  * Fix: Fix AutotoolsToolchain extraflags priority
    [gh#conan-io/conan#15005].
  * Fix: Remove colors from conan --version output
    [gh#conan-io/conan#15002].
  * Fix: Add an error message if the sqlite3 version is
    unsupported (less than 3.7.11 from 2012)
    [gh#conan-io/conan#14950].
  * Fix: Make cache DB always use forward slash for paths, to be
    uniform across Windows and Linux [gh#conan-io/conan#14940].
  * Fix: Solve re-build of an existing package revision (like
    forcing rebuild of a an existing header-only package), while
    previous folder was still used by other projects
    [gh#conan-io/conan#14938].
  * Fix: Avoid a recipe mutating a conf to affect other recipes
    [gh#conan-io/conan#14932].
  * Fix: The output of system packages via Apt.install() or
    PkgConfig.fill_cpp_info, like xorg/system was very noisy to
    the Conan output, making it more quiet
    [gh#conan-io/conan#14924].
  * Fix: Serialize the path information of python_requires,
    necessary for computing buildinfo [gh#conan-io/conan#14886].
  * Fix: Define remotes in conan source command in case recipe has
    python_requires that need to be downloaded from remotes
    [gh#conan-io/conan#14852].
  * Fix: Fix min target flag for xros and xros-simulator
    [gh#conan-io/conan#14776].
  * Bugfix: --build=missing was doing unnecessary builds of
    packages that were not needed and could be skipped, in the
    case of tool_requires having transitive dependencies
    [gh#conan-io/conan#15082].
  * BugFix: Add package revision to format=json in 'conan
    export-pkg' command [gh#conan-io/conan#15042].
  * Bugfix: tools.build:download_source=True will not fail when
    there are editable packages [gh#conan-io/conan#15004].
  * Bugfix: Transitive dependencies were incorrectly added to
    conandeps.xcconfig [gh#conan-io/conan#14898].
  * Bugfix: Fix integrity-check (upload --check or cache
    check-integrity) when the export_source has not been
    downloaded [gh#conan-io/conan#14850].
  * Bugfix: Properly lock release candidates of python requires
    [gh#conan-io/conan#14846].
  * BugFix: Version ranges ending with - do not automatically
    activate pre-releases resolution in the full range
    [gh#conan-io/conan#14814].
  * BugFix: Fix version ranges so pre-releases are correctly
    included in the lower bound and excluded in the upper bound
    [gh#conan-io/conan#14814].
- New Requires: python-distro.
* Fri Oct 27 2023 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
